@@ -253,7 +253,7 @@ static void eap_tls_handle_request(struct eap_state *eap,
 
 	if (!tls->rx_pkt_buf && (flags & EAP_TLS_FLAG_M)) {
 		if (!(flags & EAP_TLS_FLAG_L)) {
-			l_error("EAP-TLS requst 1st fragment with no length");
+			l_error("EAP-TLS request 1st fragment with no length");
 
 			goto err;
 		}
@@ -478,7 +478,8 @@ static int eap_tls_check_settings(struct l_settings *settings,
 			 */
 			eap_append_secret(out_missing,
 					EAP_SECRET_LOCAL_PKEY_PASSPHRASE,
-					passphrase_setting, NULL, path);
+					passphrase_setting, NULL, path,
+					EAP_CACHE_TEMPORARY);
 		} else {
 			memset(priv_key, 0, size);
 			l_free(priv_key);
