@@ -58,6 +58,8 @@ struct wiphy {
 	uint8_t max_num_ssids_per_scan;
 	bool support_scheduled_scan:1;
 	bool support_rekey_offload:1;
+	bool support_adhoc_rsn:1;
+	uint16_t supported_iftypes;
 	uint16_t supported_ciphers;
 	struct scan_freq_set *supported_freqs;
 	char *model_str;
@@ -201,6 +203,36 @@ uint8_t wiphy_get_max_num_ssids_per_scan(struct wiphy *wiphy)
 	return wiphy->max_num_ssids_per_scan;
 }
 
+bool wiphy_supports_adhoc_rsn(struct wiphy *wiphy)
+{
+	return wiphy->support_adhoc_rsn;
+}
+
+static char **wiphy_get_supported_iftypes(struct wiphy *wiphy)
+{
+	char **ret = l_new(char *,
+			__builtin_popcount(wiphy->supported_iftypes) + 1);
+	unsigned int i;
+	unsigned int j;
+
+	for (j = 0, i = 0; i < sizeof(wiphy->supported_iftypes) * 8; i++) {
+		if (!(wiphy->supported_iftypes & (1 << i)))
+			continue;
+
+		ret[j++] = l_strdup(dbus_iftype_to_string(i + 1));
+	}
+
+	return ret;
+}
+
+bool wiphy_supports_iftype(struct wiphy *wiphy, uint32_t iftype)
+{
+	if (iftype > sizeof(wiphy->supported_iftypes) * 8)
+		return false;
+
+	return wiphy->supported_iftypes & (1 << (iftype - 1));
+}
+
 static void wiphy_print_basic_info(struct wiphy *wiphy)
 {
 	uint32_t bands;
@@ -240,6 +272,16 @@ static void wiphy_print_basic_info(struct wiphy *wiphy)
 
 		l_info("%s", buf);
 	}
+
+	if (wiphy->supported_iftypes) {
+		char **iftypes = wiphy_get_supported_iftypes(wiphy);
+		char *joined = l_strjoinv(iftypes, ' ');
+
+		l_info("\tSupported iftypes: %s", joined);
+
+		l_free(joined);
+		l_strfreev(iftypes);
+	}
 }
 
 static void parse_supported_commands(struct wiphy *wiphy,
@@ -346,6 +388,26 @@ static void parse_supported_bands(struct wiphy *wiphy,
 	}
 }
 
+static void parse_supported_iftypes(struct wiphy *wiphy,
+						struct l_genl_attr *attr)
+{
+	uint16_t type, len;
+	const void *data;
+
+	while (l_genl_attr_next(attr, &type, &len, &data)) {
+		/*
+		 * NL80211_IFTYPE_UNSPECIFIED can be ignored, so we start
+		 * at the first bit
+		 */
+		if (type > sizeof(wiphy->supported_iftypes) * 8) {
+			l_warn("unsupported iftype: %u", type);
+			continue;
+		}
+
+		wiphy->supported_iftypes |= 1 << (type - 1);
+	}
+}
+
 static void wiphy_parse_attributes(struct wiphy *wiphy,
 					struct l_genl_attr *attr)
 {
@@ -388,6 +450,13 @@ static void wiphy_parse_attributes(struct wiphy *wiphy,
 				wiphy->max_num_ssids_per_scan =
 							*((uint8_t *) data);
 			break;
+		case NL80211_ATTR_SUPPORT_IBSS_RSN:
+			wiphy->support_adhoc_rsn = true;
+			break;
+		case NL80211_ATTR_SUPPORTED_IFTYPES:
+			if (l_genl_attr_recurse(attr, &nested))
+				parse_supported_iftypes(wiphy, &nested);
+			break;
 		}
 	}
 
@@ -836,6 +905,26 @@ static bool wiphy_property_get_name(struct l_dbus *dbus,
 	return true;
 }
 
+static bool wiphy_property_get_supported_modes(struct l_dbus *dbus,
+					struct l_dbus_message *message,
+					struct l_dbus_message_builder *builder,
+					void *user_data)
+{
+	struct wiphy *wiphy = user_data;
+	unsigned int j = 0;
+	char **iftypes = wiphy_get_supported_iftypes(wiphy);
+
+	l_dbus_message_builder_enter_array(builder, "s");
+
+	while (iftypes[j])
+		l_dbus_message_builder_append_basic(builder, 's', iftypes[j++]);
+
+	l_dbus_message_builder_leave_array(builder);
+	l_strfreev(iftypes);
+
+	return true;
+}
+
 static void setup_wiphy_interface(struct l_dbus_interface *interface)
 {
 	l_dbus_interface_property(interface, "Powered", 0, "b",
@@ -847,6 +936,9 @@ static void setup_wiphy_interface(struct l_dbus_interface *interface)
 					wiphy_property_get_vendor, NULL);
 	l_dbus_interface_property(interface, "Name", 0, "s",
 					wiphy_property_get_name, NULL);
+	l_dbus_interface_property(interface, "SupportedModes", 0, "as",
+					wiphy_property_get_supported_modes,
+					NULL);
 }
 
 bool wiphy_init(struct l_genl_family *in, const char *whitelist,
