@@ -42,6 +42,30 @@
 #include "src/ie.h"
 #include "src/handshake.h"
 
+struct test_handshake_state {
+	struct handshake_state super;
+};
+
+static void test_handshake_state_free(struct handshake_state *hs)
+{
+	struct test_handshake_state *ths =
+			container_of(hs, struct test_handshake_state, super);
+
+	l_free(ths);
+}
+
+static struct handshake_state *test_handshake_state_new(uint32_t ifindex)
+{
+	struct test_handshake_state *ths;
+
+	ths = l_new(struct test_handshake_state, 1);
+
+	ths->super.ifindex = ifindex;
+	ths->super.free = test_handshake_state_free;
+
+	return &ths->super;
+}
+
 static const unsigned char wsc_attrs1[] = {
 	0x10, 0x4a, 0x00, 0x01, 0x10, 0x10, 0x44, 0x00, 0x01, 0x02, 0x10, 0x41,
 	0x00, 0x01, 0x01, 0x10, 0x12, 0x00, 0x02, 0x00, 0x04, 0x10, 0x53, 0x00,
@@ -1907,14 +1931,20 @@ struct verify_data {
 	verify.expected = e;				\
 	verify.expected_len = sizeof(e)
 
-static void verify_deauthenticate(uint32_t ifindex, const uint8_t *aa,
-				const uint8_t *spa, uint16_t reason_code,
-				void *user_data)
+static void verify_handshake_event(struct handshake_state *hs,
+		enum handshake_event event, void *event_data, void *user_data)
 {
 	struct verify_data *data = user_data;
 
-	assert(reason_code == MMPDU_REASON_CODE_IEEE8021X_FAILED);
-	data->eapol_failed = true;
+	switch (event) {
+	case HANDSHAKE_EVENT_FAILED:
+		assert(l_get_u16(event_data) ==
+				MMPDU_REASON_CODE_IEEE8021X_FAILED);
+		data->eapol_failed = true;
+		break;
+	default:
+		break;
+	}
 }
 
 static int verify_8021x(uint32_t ifindex,
@@ -1963,16 +1993,16 @@ static void wsc_test_pbc_handshake(const void *data)
 	eap_init(1400);
 	eapol_init();
 
-	hs = handshake_state_new(1);
+	hs = test_handshake_state_new(1);
 	sm = eapol_sm_new(hs);
 	eapol_register(sm);
 
 	handshake_state_set_authenticator_address(hs, ap_address);
 	handshake_state_set_supplicant_address(hs, sta_address);
+	handshake_state_set_event_func(hs, verify_handshake_event, &verify);
 
 	__eapol_set_tx_packet_func(verify_8021x);
 	__eapol_set_tx_user_data(&verify);
-	__eapol_set_deauthenticate_func(verify_deauthenticate);
 	eapol_sm_set_user_data(sm, &verify);
 	eapol_sm_set_event_func(sm, verify_credential);
 
@@ -2071,16 +2101,16 @@ static void wsc_test_retransmission_no_fragmentation(const void *data)
 	eap_init(1400);
 	eapol_init();
 
-	hs = handshake_state_new(1);
+	hs = test_handshake_state_new(1);
 	sm = eapol_sm_new(hs);
 	eapol_register(sm);
 
 	handshake_state_set_authenticator_address(hs, ap_address);
 	handshake_state_set_supplicant_address(hs, sta_address);
+	handshake_state_set_event_func(hs, verify_handshake_event, &verify);
 
 	__eapol_set_tx_packet_func(verify_8021x);
 	__eapol_set_tx_user_data(&verify);
-	__eapol_set_deauthenticate_func(verify_deauthenticate);
 	eapol_sm_set_user_data(sm, &verify);
 	eapol_sm_set_event_func(sm, verify_credential);
 
